@@ -12,7 +12,6 @@ import subprocess
 import zc.buildout
 
 import six.moves.urllib as urllib
-from six import text_type as str
 
 import hexagonit.recipe.download
 
@@ -122,8 +121,7 @@ class Recipe(object):
                     'rubygems-%s.zip' % self.version, self.version)
 
         f = urllib.request.urlopen('http://rubygems.org/pages/download')
-        s = f.read()
-        s = str(s)
+        s = f.read().decode('utf-8')
         f.close()
         r = re.search(r'http://production.cf.rubygems.org/rubygems/'
                       r'rubygems-([0-9.]+).zip', s)
